package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Aug 10, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
go-builtin
some builtin in Golang developed with generics (golang 1.18)
Documentation
¶
Generic function that performs a == b
Generic function that performs a > b
func GreaterEqual[T Ord](a, b T) bool
Generic function that performs a >= b
Generic function that performs a < b
Generic function that performs a <= b
type Compf[T any] func(a, b T) bool
Function type to do comparing operation
Function type to do equality operation
Function type to do ordering operation
Source Files
¶
Click to show internal directories.
Click to hide internal directories.